==> blue2-xplore-booking-plugin-1.2.4-4787a6.tar: assets/redux/actions.js <==
import * as ACTIONS from './actionTypes';

//CART
export const changeJourneyType = type => ({
    type: ACTIONS.CHANGE_JOURNEY_TYPE,
    payload: {
        type
    }
});

export const changeDirection = () => ({
    type: ACTIONS.CHANGE_DIRECTION
});

export const setDepartureDate = date => ({
    type: ACTIONS.SET_DEPARTURE_DATE,
    payload: {
        date
    }
});

export const setReturnDate = date => ({
    type: ACTIONS.SET_RETURN_DATE,
    payload: {
        date
    }
});

export const addTicketToCart = id => ({
    type: ACTIONS.ADD_TICKET_TO_CART,
    payload: id
});

export const removeTicketFromCart = id => ({
    type: ACTIONS.REMOVE_TICKET_FROM_CART,
    payload: id
});

export const updateAddons = field => ({
    type: ACTIONS.UPDATE_ADDONS,
    payload: {
        key: field.name,
        value: field.value
    }
});

export const setTerms = value => ({
    type: ACTIONS.SET_TERMS,
    payload: value
});

export const addJourney = (journey, direction) => ({
    type: ACTIONS.ADD_JOURNEY,
    payload: {
        journey,
        direction
    }
});

//TICKETS
export const addTickets = tickets => ({
    type: ACTIONS.ADD_TICKETS,
    payload: tickets
});

//USER
export const updateUser = field => ({
    type: ACTIONS.UPDATE_USER,
    payload: {
        key: field.name,
        value: field.value
    }
});

//ROUTE
export const progressRoute = () => ({
    type: ACTIONS.PROGRESS_ROUTE
});

export const previousRoute = () => ({
    type: ACTIONS.PREVIOUS_ROUTE
});

//BOOKING
export const addBooking = bookingId => ({
    type: ACTIONS.ADD_BOOKING,
    payload: {
        bookingId
    }
});

==> blue2-xplore-booking-plugin-1.3.1-94aa01.tar: assets/redux/actions.js <==
import * as ACTIONS from './actionTypes';

//CART
export const changeJourneyType = type => ({
    type: ACTIONS.CHANGE_JOURNEY_TYPE,
    payload: {
        type
    }
});

export const changeDirection = () => ({
    type: ACTIONS.CHANGE_DIRECTION
});

export const setDepartureDate = date => ({
    type: ACTIONS.SET_DEPARTURE_DATE,
    payload: {
        date
    }
});

export const setReturnDate = date => ({
    type: ACTIONS.SET_RETURN_DATE,
    payload: {
        date
    }
});

export const addTicketToCart = ticket => ({
    type: ACTIONS.ADD_TICKET_TO_CART,
    payload: ticket
});

export const removeTicketFromCart = id => ({
    type: ACTIONS.REMOVE_TICKET_FROM_CART,
    payload: id
});

export const updateAddons = field => ({
    type: ACTIONS.UPDATE_ADDONS,
    payload: {
        key: field.name,
        value: field.value
    }
});

export const setTerms = value => ({
    type: ACTIONS.SET_TERMS,
    payload: value
});

export const addJourney = (journey, direction) => ({
    type: ACTIONS.ADD_JOURNEY,
    payload: {
        journey,
        direction
    }
});

//TICKETS
export const addTickets = tickets => ({
    type: ACTIONS.ADD_TICKETS,
    payload: tickets
});

//USER
export const updateUser = field => ({
    type: ACTIONS.UPDATE_USER,
    payload: {
        key: field.name,
        value: field.value
    }
});

//ROUTE
export const progressRoute = () => ({
    type: ACTIONS.PROGRESS_ROUTE
});

export const previousRoute = () => ({
    type: ACTIONS.PREVIOUS_ROUTE
});

//BOOKING
export const addBooking = bookingId => ({
    type: ACTIONS.ADD_BOOKING,
    payload: {
        bookingId
    }
});
